(function (global, factory) {
    typeof exports === 'object' && typeof module !== 'undefined' ? module.exports = factory() :
    typeof define === 'function' && define.amd ? define(factory) :
    (global = typeof globalThis !== 'undefined' ? globalThis : global || self, (global.Pdf = global.Pdf || {}, global.Pdf.svelte = factory()));
}(this, (function () { 'use strict';

    function noop() { }
    function assign(tar, src) {
        // @ts-ignore
        for (const k in src)
            tar[k] = src[k];
        return tar;
    }
    function run(fn) {
        return fn();
    }
    function blank_object() {
        return Object.create(null);
    }
    function run_all(fns) {
        fns.forEach(run);
    }
    function is_function(thing) {
        return typeof thing === 'function';
    }
    function safe_not_equal(a, b) {
        return a != a ? b == b : a !== b || ((a && typeof a === 'object') || typeof a === 'function');
    }
    function is_empty(obj) {
        return Object.keys(obj).length === 0;
    }
    function create_slot(definition, ctx, $$scope, fn) {
        if (definition) {
            const slot_ctx = get_slot_context(definition, ctx, $$scope, fn);
            return definition[0](slot_ctx);
        }
    }
    function get_slot_context(definition, ctx, $$scope, fn) {
        return definition[1] && fn
            ? assign($$scope.ctx.slice(), definition[1](fn(ctx)))
            : $$scope.ctx;
    }
    function get_slot_changes(definition, $$scope, dirty, fn) {
        if (definition[2] && fn) {
            const lets = definition[2](fn(dirty));
            if ($$scope.dirty === undefined) {
                return lets;
            }
            if (typeof lets === 'object') {
                const merged = [];
                const len = Math.max($$scope.dirty.length, lets.length);
                for (let i = 0; i < len; i += 1) {
                    merged[i] = $$scope.dirty[i] | lets[i];
                }
                return merged;
            }
            return $$scope.dirty | lets;
        }
        return $$scope.dirty;
    }
    function update_slot_base(slot, slot_definition, ctx, $$scope, slot_changes, get_slot_context_fn) {
        if (slot_changes) {
            const slot_context = get_slot_context(slot_definition, ctx, $$scope, get_slot_context_fn);
            slot.p(slot_context, slot_changes);
        }
    }
    function get_all_dirty_from_scope($$scope) {
        if ($$scope.ctx.length > 32) {
            const dirty = [];
            const length = $$scope.ctx.length / 32;
            for (let i = 0; i < length; i++) {
                dirty[i] = -1;
            }
            return dirty;
        }
        return -1;
    }
    function null_to_empty(value) {
        return value == null ? '' : value;
    }
    function append(target, node) {
        target.appendChild(node);
    }
    function insert(target, node, anchor) {
        target.insertBefore(node, anchor || null);
    }
    function detach(node) {
        if (node.parentNode) {
            node.parentNode.removeChild(node);
        }
    }
    function element(name) {
        return document.createElement(name);
    }
    function text(data) {
        return document.createTextNode(data);
    }
    function space() {
        return text(' ');
    }
    function listen(node, event, handler, options) {
        node.addEventListener(event, handler, options);
        return () => node.removeEventListener(event, handler, options);
    }
    function attr(node, attribute, value) {
        if (value == null)
            node.removeAttribute(attribute);
        else if (node.getAttribute(attribute) !== value)
            node.setAttribute(attribute, value);
    }
    function children(element) {
        return Array.from(element.childNodes);
    }
    function set_data(text, data) {
        data = '' + data;
        if (text.data === data)
            return;
        text.data = data;
    }
    function custom_event(type, detail, { bubbles = false, cancelable = false } = {}) {
        const e = document.createEvent('CustomEvent');
        e.initCustomEvent(type, bubbles, cancelable, detail);
        return e;
    }

    let current_component;
    function set_current_component(component) {
        current_component = component;
    }
    function get_current_component() {
        if (!current_component)
            throw new Error('Function called outside component initialization');
        return current_component;
    }
    /**
     * The `onMount` function schedules a callback to run as soon as the component has been mounted to the DOM.
     * It must be called during the component's initialisation (but doesn't need to live *inside* the component;
     * it can be called from an external module).
     *
     * `onMount` does not run inside a [server-side component](/docs#run-time-server-side-component-api).
     *
     * https://svelte.dev/docs#run-time-svelte-onmount
     */
    function onMount(fn) {
        get_current_component().$$.on_mount.push(fn);
    }
    /**
     * Creates an event dispatcher that can be used to dispatch [component events](/docs#template-syntax-component-directives-on-eventname).
     * Event dispatchers are functions that can take two arguments: `name` and `detail`.
     *
     * Component events created with `createEventDispatcher` create a
     * [CustomEvent](https://developer.mozilla.org/en-US/docs/Web/API/CustomEvent).
     * These events do not [bubble](https://developer.mozilla.org/en-US/docs/Learn/JavaScript/Building_blocks/Events#Event_bubbling_and_capture).
     * The `detail` argument corresponds to the [CustomEvent.detail](https://developer.mozilla.org/en-US/docs/Web/API/CustomEvent/detail)
     * property and can contain any type of data.
     *
     * https://svelte.dev/docs#run-time-svelte-createeventdispatcher
     */
    function createEventDispatcher() {
        const component = get_current_component();
        return (type, detail, { cancelable = false } = {}) => {
            const callbacks = component.$$.callbacks[type];
            if (callbacks) {
                // TODO are there situations where events could be dispatched
                // in a server (non-DOM) environment?
                const event = custom_event(type, detail, { cancelable });
                callbacks.slice().forEach(fn => {
                    fn.call(component, event);
                });
                return !event.defaultPrevented;
            }
            return true;
        };
    }

    const dirty_components = [];
    const binding_callbacks = [];
    let render_callbacks = [];
    const flush_callbacks = [];
    const resolved_promise = /* @__PURE__ */ Promise.resolve();
    let update_scheduled = false;
    function schedule_update() {
        if (!update_scheduled) {
            update_scheduled = true;
            resolved_promise.then(flush);
        }
    }
    function add_render_callback(fn) {
        render_callbacks.push(fn);
    }
    // flush() calls callbacks in this order:
    // 1. All beforeUpdate callbacks, in order: parents before children
    // 2. All bind:this callbacks, in reverse order: children before parents.
    // 3. All afterUpdate callbacks, in order: parents before children. EXCEPT
    //    for afterUpdates called during the initial onMount, which are called in
    //    reverse order: children before parents.
    // Since callbacks might update component values, which could trigger another
    // call to flush(), the following steps guard against this:
    // 1. During beforeUpdate, any updated components will be added to the
    //    dirty_components array and will cause a reentrant call to flush(). Because
    //    the flush index is kept outside the function, the reentrant call will pick
    //    up where the earlier call left off and go through all dirty components. The
    //    current_component value is saved and restored so that the reentrant call will
    //    not interfere with the "parent" flush() call.
    // 2. bind:this callbacks cannot trigger new flush() calls.
    // 3. During afterUpdate, any updated components will NOT have their afterUpdate
    //    callback called a second time; the seen_callbacks set, outside the flush()
    //    function, guarantees this behavior.
    const seen_callbacks = new Set();
    let flushidx = 0; // Do *not* move this inside the flush() function
    function flush() {
        // Do not reenter flush while dirty components are updated, as this can
        // result in an infinite loop. Instead, let the inner flush handle it.
        // Reentrancy is ok afterwards for bindings etc.
        if (flushidx !== 0) {
            return;
        }
        const saved_component = current_component;
        do {
            // first, call beforeUpdate functions
            // and update components
            try {
                while (flushidx < dirty_components.length) {
                    const component = dirty_components[flushidx];
                    flushidx++;
                    set_current_component(component);
                    update(component.$$);
                }
            }
            catch (e) {
                // reset dirty state to not end up in a deadlocked state and then rethrow
                dirty_components.length = 0;
                flushidx = 0;
                throw e;
            }
            set_current_component(null);
            dirty_components.length = 0;
            flushidx = 0;
            while (binding_callbacks.length)
                binding_callbacks.pop()();
            // then, once components are updated, call
            // afterUpdate functions. This may cause
            // subsequent updates...
            for (let i = 0; i < render_callbacks.length; i += 1) {
                const callback = render_callbacks[i];
                if (!seen_callbacks.has(callback)) {
                    // ...so guard against infinite loops
                    seen_callbacks.add(callback);
                    callback();
                }
            }
            render_callbacks.length = 0;
        } while (dirty_components.length);
        while (flush_callbacks.length) {
            flush_callbacks.pop()();
        }
        update_scheduled = false;
        seen_callbacks.clear();
        set_current_component(saved_component);
    }
    function update($$) {
        if ($$.fragment !== null) {
            $$.update();
            run_all($$.before_update);
            const dirty = $$.dirty;
            $$.dirty = [-1];
            $$.fragment && $$.fragment.p($$.ctx, dirty);
            $$.after_update.forEach(add_render_callback);
        }
    }
    /**
     * Useful for example to execute remaining `afterUpdate` callbacks before executing `destroy`.
     */
    function flush_render_callbacks(fns) {
        const filtered = [];
        const targets = [];
        render_callbacks.forEach((c) => fns.indexOf(c) === -1 ? filtered.push(c) : targets.push(c));
        targets.forEach((c) => c());
        render_callbacks = filtered;
    }
    const outroing = new Set();
    let outros;
    function transition_in(block, local) {
        if (block && block.i) {
            outroing.delete(block);
            block.i(local);
        }
    }
    function transition_out(block, local, detach, callback) {
        if (block && block.o) {
            if (outroing.has(block))
                return;
            outroing.add(block);
            outros.c.push(() => {
                outroing.delete(block);
                if (callback) {
                    if (detach)
                        block.d(1);
                    callback();
                }
            });
            block.o(local);
        }
        else if (callback) {
            callback();
        }
    }
    function mount_component(component, target, anchor, customElement) {
        const { fragment, after_update } = component.$$;
        fragment && fragment.m(target, anchor);
        if (!customElement) {
            // onMount happens before the initial afterUpdate
            add_render_callback(() => {
                const new_on_destroy = component.$$.on_mount.map(run).filter(is_function);
                // if the component was destroyed immediately
                // it will update the `$$.on_destroy` reference to `null`.
                // the destructured on_destroy may still reference to the old array
                if (component.$$.on_destroy) {
                    component.$$.on_destroy.push(...new_on_destroy);
                }
                else {
                    // Edge case - component was destroyed immediately,
                    // most likely as a result of a binding initialising
                    run_all(new_on_destroy);
                }
                component.$$.on_mount = [];
            });
        }
        after_update.forEach(add_render_callback);
    }
    function destroy_component(component, detaching) {
        const $$ = component.$$;
        if ($$.fragment !== null) {
            flush_render_callbacks($$.after_update);
            run_all($$.on_destroy);
            $$.fragment && $$.fragment.d(detaching);
            // TODO null out other refs, including component.$$ (but need to
            // preserve final state?)
            $$.on_destroy = $$.fragment = null;
            $$.ctx = [];
        }
    }
    function make_dirty(component, i) {
        if (component.$$.dirty[0] === -1) {
            dirty_components.push(component);
            schedule_update();
            component.$$.dirty.fill(0);
        }
        component.$$.dirty[(i / 31) | 0] |= (1 << (i % 31));
    }
    function init(component, options, instance, create_fragment, not_equal, props, append_styles, dirty = [-1]) {
        const parent_component = current_component;
        set_current_component(component);
        const $$ = component.$$ = {
            fragment: null,
            ctx: [],
            // state
            props,
            update: noop,
            not_equal,
            bound: blank_object(),
            // lifecycle
            on_mount: [],
            on_destroy: [],
            on_disconnect: [],
            before_update: [],
            after_update: [],
            context: new Map(options.context || (parent_component ? parent_component.$$.context : [])),
            // everything else
            callbacks: blank_object(),
            dirty,
            skip_bound: false,
            root: options.target || parent_component.$$.root
        };
        append_styles && append_styles($$.root);
        let ready = false;
        $$.ctx = instance
            ? instance(component, options.props || {}, (i, ret, ...rest) => {
                const value = rest.length ? rest[0] : ret;
                if ($$.ctx && not_equal($$.ctx[i], $$.ctx[i] = value)) {
                    if (!$$.skip_bound && $$.bound[i])
                        $$.bound[i](value);
                    if (ready)
                        make_dirty(component, i);
                }
                return ret;
            })
            : [];
        $$.update();
        ready = true;
        run_all($$.before_update);
        // `false` as a special case of no DOM component
        $$.fragment = create_fragment ? create_fragment($$.ctx) : false;
        if (options.target) {
            if (options.hydrate) {
                const nodes = children(options.target);
                // eslint-disable-next-line @typescript-eslint/no-non-null-assertion
                $$.fragment && $$.fragment.l(nodes);
                nodes.forEach(detach);
            }
            else {
                // eslint-disable-next-line @typescript-eslint/no-non-null-assertion
                $$.fragment && $$.fragment.c();
            }
            if (options.intro)
                transition_in(component.$$.fragment);
            mount_component(component, options.target, options.anchor, options.customElement);
            flush();
        }
        set_current_component(parent_component);
    }
    /**
     * Base class for Svelte components. Used when dev=false.
     */
    class SvelteComponent {
        $destroy() {
            destroy_component(this, 1);
            this.$destroy = noop;
        }
        $on(type, callback) {
            if (!is_function(callback)) {
                return noop;
            }
            const callbacks = (this.$$.callbacks[type] || (this.$$.callbacks[type] = []));
            callbacks.push(callback);
            return () => {
                const index = callbacks.indexOf(callback);
                if (index !== -1)
                    callbacks.splice(index, 1);
            };
        }
        $set($$props) {
            if (this.$$set && !is_empty($$props)) {
                this.$$.skip_bound = true;
                this.$$set($$props);
                this.$$.skip_bound = false;
            }
        }
    }

    /* src/pdf.svelte generated by Svelte v3.59.2 */

    function fallback_block(ctx) {
    	let div;
    	let button0;
    	let t1;
    	let t2_value = /*getPageText*/ ctx[7](/*currentPage*/ ctx[0], /*numPages*/ ctx[6]) + "";
    	let t2;
    	let t3;
    	let button1;
    	let div_class_value;
    	let mounted;
    	let dispose;

    	return {
    		c() {
    			div = element("div");
    			button0 = element("button");
    			button0.textContent = "Previous";
    			t1 = space();
    			t2 = text(t2_value);
    			t3 = space();
    			button1 = element("button");
    			button1.textContent = "Next";
    			attr(button0, "class", "svelte-mubutj");
    			attr(button1, "class", "svelte-mubutj");
    			attr(div, "class", div_class_value = "" + (null_to_empty(generateClasses("controls", /*classes*/ ctx[1].controls)) + " svelte-mubutj"));
    		},
    		m(target, anchor) {
    			insert(target, div, anchor);
    			append(div, button0);
    			append(div, t1);
    			append(div, t2);
    			append(div, t3);
    			append(div, button1);

    			if (!mounted) {
    				dispose = [
    					listen(button0, "click", /*navigateLeft*/ ctx[2]),
    					listen(button1, "click", /*navigateRight*/ ctx[3])
    				];

    				mounted = true;
    			}
    		},
    		p(ctx, dirty) {
    			if (dirty & /*currentPage, numPages*/ 65 && t2_value !== (t2_value = /*getPageText*/ ctx[7](/*currentPage*/ ctx[0], /*numPages*/ ctx[6]) + "")) set_data(t2, t2_value);

    			if (dirty & /*classes*/ 2 && div_class_value !== (div_class_value = "" + (null_to_empty(generateClasses("controls", /*classes*/ ctx[1].controls)) + " svelte-mubutj"))) {
    				attr(div, "class", div_class_value);
    			}
    		},
    		d(detaching) {
    			if (detaching) detach(div);
    			mounted = false;
    			run_all(dispose);
    		}
    	};
    }

    function create_fragment(ctx) {
    	let div1;
    	let t;
    	let div0;
    	let canvas;
    	let div0_class_value;
    	let div1_class_value;
    	let current;
    	let mounted;
    	let dispose;
    	const default_slot_template = /*#slots*/ ctx[18].default;
    	const default_slot = create_slot(default_slot_template, ctx, /*$$scope*/ ctx[17], null);
    	const default_slot_or_fallback = default_slot || fallback_block(ctx);

    	return {
    		c() {
    			div1 = element("div");
    			if (default_slot_or_fallback) default_slot_or_fallback.c();
    			t = space();
    			div0 = element("div");
    			canvas = element("canvas");
    			attr(canvas, "class", "svelte-mubutj");
    			attr(div0, "class", div0_class_value = "" + (null_to_empty(generateClasses("viewer", /*classes*/ ctx[1].container)) + " svelte-mubutj"));
    			attr(div1, "class", div1_class_value = "" + (null_to_empty(generateClasses("pdf-svelte", "theme-" + /*opts*/ ctx[5].theme, "display-" + /*opts*/ ctx[5].display, /*classes*/ ctx[1].overall)) + " svelte-mubutj"));
    		},
    		m(target, anchor) {
    			insert(target, div1, anchor);

    			if (default_slot_or_fallback) {
    				default_slot_or_fallback.m(div1, null);
    			}

    			append(div1, t);
    			append(div1, div0);
    			append(div0, canvas);
    			/*div0_binding*/ ctx[19](div0);
    			current = true;

    			if (!mounted) {
    				dispose = listen(div0, "dblclick", /*autoZoom*/ ctx[8]);
    				mounted = true;
    			}
    		},
    		p(ctx, [dirty]) {
    			if (default_slot) {
    				if (default_slot.p && (!current || dirty & /*$$scope*/ 131072)) {
    					update_slot_base(
    						default_slot,
    						default_slot_template,
    						ctx,
    						/*$$scope*/ ctx[17],
    						!current
    						? get_all_dirty_from_scope(/*$$scope*/ ctx[17])
    						: get_slot_changes(default_slot_template, /*$$scope*/ ctx[17], dirty, null),
    						null
    					);
    				}
    			} else {
    				if (default_slot_or_fallback && default_slot_or_fallback.p && (!current || dirty & /*classes, currentPage, numPages*/ 67)) {
    					default_slot_or_fallback.p(ctx, !current ? -1 : dirty);
    				}
    			}

    			if (!current || dirty & /*classes*/ 2 && div0_class_value !== (div0_class_value = "" + (null_to_empty(generateClasses("viewer", /*classes*/ ctx[1].container)) + " svelte-mubutj"))) {
    				attr(div0, "class", div0_class_value);
    			}

    			if (!current || dirty & /*opts, classes*/ 34 && div1_class_value !== (div1_class_value = "" + (null_to_empty(generateClasses("pdf-svelte", "theme-" + /*opts*/ ctx[5].theme, "display-" + /*opts*/ ctx[5].display, /*classes*/ ctx[1].overall)) + " svelte-mubutj"))) {
    				attr(div1, "class", div1_class_value);
    			}
    		},
    		i(local) {
    			if (current) return;
    			transition_in(default_slot_or_fallback, local);
    			current = true;
    		},
    		o(local) {
    			transition_out(default_slot_or_fallback, local);
    			current = false;
    		},
    		d(detaching) {
    			if (detaching) detach(div1);
    			if (default_slot_or_fallback) default_slot_or_fallback.d(detaching);
    			/*div0_binding*/ ctx[19](null);
    			mounted = false;
    			dispose();
    		}
    	};
    }

    const autoZoomMin = 1, autoZoomMax = 1.5;

    function debounce(func, timeout = 500) {
    	let timer;

    	return (...args) => {
    		if (!timer) {
    			// First call is leading edge (call immediately)
    			func.apply(this, args);

    			timer = setTimeout(() => timer = undefined, timeout);
    		} else {
    			// Subsequent calls are trailing edge (wait until they stop)
    			clearTimeout(timer);

    			timer = setTimeout(
    				() => {
    					func.apply(this, args);
    					timer = undefined;
    				},
    				timeout
    			);
    		}
    	};
    }

    function generateClasses() {
    	return Array.from(arguments).filter(a => a).join(" ");
    }

    function instance($$self, $$props, $$invalidate) {
    	let opts;
    	let { $$slots: slots = {}, $$scope } = $$props;
    	const dispatch = createEventDispatcher();
    	let pdfjs;

    	onMount(async () => {
    		pdfjs = await import('pdfjs-dist');
    		await Promise.resolve().then(function () { return pdf_worker_entry; });
    	});

    	let { pdf } = $$props;
    	let { classes = {} } = $$props;
    	let { options = {} } = $$props;
    	let { zoom = 1 } = $$props;
    	let { currentPage = 1 } = $$props;
    	let { pageNumberText = (currentPage, maximumPages) => currentPage + "/" + maximumPages } = $$props;

    	const defaultOptions = {
    		// paged, all
    		display: "paged",
    		// dark, light
    		theme: 'dark',
    		autoZoomEnabled: false,
    		upscale: 4,
    		pdfjs: {}
    	};

    	let pageContainer = null;
    	let doc = null;
    	let numPages = 0;
    	let pages = [];
    	let oldZoom = 0;

    	const render = debounce(async () => {
    		doc = null;
    		$$invalidate(15, pages = null);
    		if (!pdf) return;
    		doc = await pdfjs.getDocument(pdf).promise;
    		$$invalidate(6, numPages = doc.numPages);

    		// Load every page asynchronously
    		$$invalidate(15, pages = (await Promise.all(Array.from(Array(numPages).keys(), pageNum => doc.getPage(pageNum + 1)))).map(page => {
    			const canvas = document.createElement('canvas');
    			canvas.classList = getComponentClass();
    			let viewport = page.getViewport({ scale: 1 });
    			const boundingRect = pageContainer.getBoundingClientRect();
    			const pageScale = Math.min(boundingRect.width / viewport.width, boundingRect.height / viewport.height);
    			viewport = viewport.clone({ scale: pageScale * opts.upscale / zoom });
    			canvas.height = viewport.height;
    			canvas.width = viewport.width;
    			canvas.style.height = `${viewport.height / opts.upscale}px`;
    			canvas.style.width = `${viewport.width / opts.upscale}px`;
    			const context = canvas.getContext('2d');
    			page.render({ canvasContext: context, viewport });
    			return canvas;
    		}));

    		$$invalidate(16, oldZoom = zoom);
    		dispatch("ready");
    	});

    	const navigateLeft = () => {
    		$$invalidate(0, currentPage = Math.max(currentPage - 1, 1));
    	};

    	const navigateRight = () => {
    		$$invalidate(0, currentPage = Math.min(currentPage + 1, numPages));
    	};

    	function getPageText(currentPage, numPages) {
    		return pageNumberText(currentPage, numPages);
    	}

    	function getComponentClass() {
    		return Array.from(pageContainer.classList).filter(c => c.startsWith("svelte"))[0];
    	}

    	// Zoom
    	const zoomLevels = [0.1, 0.25, 0.5, 0.66, 0.8, 0.9, 1, 1.2, 1.5, 2, 3, 4, 5];

    	function adjustZoom(offset) {
    		const currentIndex = zoomLevels.indexOf(zoom);
    		let newLevel = currentIndex + offset;
    		if (newLevel < 0) newLevel = 0;
    		if (newLevel >= zoomLevels.length) newLevel = zoomLevels.length - 1;
    		$$invalidate(9, zoom = zoomLevels[newLevel]);
    	}

    	function zoomIn() {
    		adjustZoom(1);
    	}

    	function zoomOut() {
    		adjustZoom(-1);
    	}

    	function autoZoom() {
    		if (config.autoZoomEnabled) $$invalidate(9, zoom = autoZoomMin >= zoom && zoom < autoZoomMax
    		? autoZoomMax
    		: autoZoomMin);
    	}

    	function div0_binding($$value) {
    		binding_callbacks[$$value ? 'unshift' : 'push'](() => {
    			pageContainer = $$value;
    			(((($$invalidate(4, pageContainer), $$invalidate(15, pages)), $$invalidate(5, opts)), $$invalidate(0, currentPage)), $$invalidate(11, options));
    		});
    	}

    	$$self.$$set = $$props => {
    		if ('pdf' in $$props) $$invalidate(10, pdf = $$props.pdf);
    		if ('classes' in $$props) $$invalidate(1, classes = $$props.classes);
    		if ('options' in $$props) $$invalidate(11, options = $$props.options);
    		if ('zoom' in $$props) $$invalidate(9, zoom = $$props.zoom);
    		if ('currentPage' in $$props) $$invalidate(0, currentPage = $$props.currentPage);
    		if ('pageNumberText' in $$props) $$invalidate(12, pageNumberText = $$props.pageNumberText);
    		if ('$$scope' in $$props) $$invalidate(17, $$scope = $$props.$$scope);
    	};

    	$$self.$$.update = () => {
    		if ($$self.$$.dirty & /*options*/ 2048) {
    			$$invalidate(5, opts = { ...defaultOptions, ...options });
    		}

    		if ($$self.$$.dirty & /*zoom*/ 512) {
    			if (zoom <= 0) $$invalidate(9, zoom = 1);
    		}

    		if ($$self.$$.dirty & /*pdf*/ 1024) {
    			render(pdf);
    		}

    		if ($$self.$$.dirty & /*zoom, oldZoom, pdf*/ 67072) {
    			if (zoom && oldZoom && zoom != oldZoom) {
    				render(pdf);
    				$$invalidate(16, oldZoom = zoom);
    			}
    		}

    		if ($$self.$$.dirty & /*pageContainer, pages, opts, currentPage*/ 32817) {
    			if (pageContainer && pages) {
    				$$invalidate(4, pageContainer.innerHTML = "", pageContainer);

    				if (opts.display == "paged") {
    					let page = pages[currentPage - 1];
    					pageContainer.append(page);
    				} else {
    					$$invalidate(0, currentPage = 1);
    					pages.forEach(page => pageContainer.append(page));
    				}
    			}
    		}
    	};

    	return [
    		currentPage,
    		classes,
    		navigateLeft,
    		navigateRight,
    		pageContainer,
    		opts,
    		numPages,
    		getPageText,
    		autoZoom,
    		zoom,
    		pdf,
    		options,
    		pageNumberText,
    		zoomIn,
    		zoomOut,
    		pages,
    		oldZoom,
    		$$scope,
    		slots,
    		div0_binding
    	];
    }

    class Pdf extends SvelteComponent {
    	constructor(options) {
    		super();

    		init(this, options, instance, create_fragment, safe_not_equal, {
    			pdf: 10,
    			classes: 1,
    			options: 11,
    			zoom: 9,
    			currentPage: 0,
    			pageNumberText: 12,
    			navigateLeft: 2,
    			navigateRight: 3,
    			zoomIn: 13,
    			zoomOut: 14
    		});
    	}

    	get navigateLeft() {
    		return this.$$.ctx[2];
    	}

    	get navigateRight() {
    		return this.$$.ctx[3];
    	}

    	get zoomIn() {
    		return this.$$.ctx[13];
    	}

    	get zoomOut() {
    		return this.$$.ctx[14];
    	}
    }

    /* Copyright 2022 Mozilla Foundation
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *     http://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */

    (typeof window !== "undefined"
      ? window
      : {}
    ).pdfjsWorker = require("./pdf.worker.js");

    var pdf_worker_entry = /*#__PURE__*/Object.freeze({
        __proto__: null
    });

    return Pdf;

})));
